@@ -203,7 +203,7 @@ void MainWindow::waitForKSycoca()
         if (KSycoca::isAvailable()) {
             return;
         }
-        // When KSycoca is not availabe that usually means Kontact
+        // When KSycoca is not available that usually means Kontact
         // was started before kded is done with it's first run
         // we want to block Kontact execution to
         // give Kded time to initialize and create the
@@ -334,7 +334,7 @@ void MainWindow::initWidgets()
 {
     QWidget *mTopWidget = new QWidget(this);
     QVBoxLayout *layout = new QVBoxLayout;
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     mTopWidget->setLayout(layout);
     setCentralWidget(mTopWidget);
@@ -385,7 +385,7 @@ void MainWindow::initAboutScreen()
 {
     QWidget *introbox = new QWidget(mPartsStack);
     QHBoxLayout *introboxHBoxLayout = new QHBoxLayout(introbox);
-    introboxHBoxLayout->setMargin(0);
+    introboxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     mPartsStack->addWidget(introbox);
     mPartsStack->setCurrentWidget(introbox);
     mIntroPart = new IntroductionWebEngineView(introbox);
